@@ -1,13 +1,13 @@
 // This may look like C code, but it is really -*- C++ -*-
 //
-// Copyright Bob Friesenhahn, 1999, 2000
+// Copyright Bob Friesenhahn, 1999, 2000, 2001
 //
 // Definition and implementation of template functions for using
 // Magick::Image with STL containers.
 //
 
-#ifndef MagickSTL_header
-#define MagickSTL_header
+#ifndef Magick_STL_header
+#define Magick_STL_header
 
 #include <algorithm>
 #include <functional>
@@ -345,15 +345,15 @@ namespace Magick
   class edgeImage : public std::unary_function<Image&,void>
   {
   public:
-    edgeImage( unsigned int order_ = 3  )
-      : _order( order_ ) { }
+    edgeImage( double radius_ = 0.0  )
+      : _radius( radius_ ) { }
 
     void operator()( Image &image_ )
       {
-	image_.edge( _order );
+	image_.edge( _radius );
       }
   private:
-    const unsigned int _order;
+    const double _radius;
   };
 
   // Emboss image (hilight edges with 3D effect)
@@ -402,6 +402,21 @@ namespace Magick
   private:
   };
 
+  // Color to use when filling drawn objects
+  class fillColorImage : public std::unary_function<Image&,void>
+  {
+  public:
+    fillColorImage( const Color &fillColor_ )
+      : _fillColor( fillColor_ ) { }
+
+    void operator()( Image &image_ )
+      {
+	image_.fillColor( _fillColor );
+      }
+  private:
+    const Color _fillColor;
+  };
+
   // Flip image (reflect each scanline in the vertical direction)
   class flipImage : public std::unary_function<Image&,void>
   {
@@ -627,6 +642,22 @@ namespace Magick
     const double _factor;
   };
 
+  // Set image validity. Valid images become empty (inValid) if
+  // argument is false.
+  class isValidImage : public std::unary_function<Image&,void>
+  {
+  public:
+    isValidImage( bool isValid_  )
+      : _isValid( isValid_ ) { }
+
+    void operator()( Image &image_ )
+      {
+	image_.isValid( _isValid );
+      }
+  private:
+    const bool _isValid;
+  };
+
   // Label image
   class labelImage : public std::unary_function<Image&,void>
   {
@@ -718,7 +749,7 @@ namespace Magick
   class medianFilterImage : public std::unary_function<Image&,void>
   {
   public:
-    medianFilterImage( unsigned int radius_ )
+    medianFilterImage( const double radius_ = 0.0 )
       : _radius( radius_ ) { }
 
     void operator()( Image &image_ )
@@ -726,7 +757,7 @@ namespace Magick
 	image_.medianFilter( _radius );
       }
   private:
-    const unsigned int _radius;
+    const double _radius;
   };
 
   // Reduce image by integral size
@@ -1000,6 +1031,22 @@ namespace Magick
     const double _sigma;
   };
 
+  // Shave pixels from image edges.
+  class shaveImage : public std::unary_function<Image&,void>
+  {
+  public:
+    shaveImage( const Geometry &geometry_ )
+      : _geometry( geometry_ ) { }
+
+    void operator()( Image &image_ )
+      {
+	image_.shave( _geometry );
+      }
+  private:
+    const Geometry _geometry;
+  };
+
+
   // Shear image (create parallelogram by sliding image by X or Y axis)
   class shearImage : public std::unary_function<Image&,void>
   {
@@ -1080,6 +1127,21 @@ namespace Magick
     const Image _rightImage;
   };
 
+  // Color to use when drawing object outlines
+  class strokeColorImage : public std::unary_function<Image&,void>
+  {
+  public:
+    strokeColorImage( const Color &strokeColor_ )
+      : _strokeColor( strokeColor_ ) { }
+
+    void operator()( Image &image_ )
+      {
+	image_.strokeColor( _strokeColor );
+      }
+  private:
+    const Color _strokeColor;
+  };
+
   // Swirl image (image pixels are rotated by degrees)
   class swirlImage : public std::unary_function<Image&,void>
   {
@@ -2132,6 +2194,22 @@ namespace Magick
     throwException( exceptionInfo );
   }
 
+  // Merge a sequence of image frames which represent image layers.
+  // This is useful for combining Photoshop layers into a single image.
+  template <class InputIterator>
+  void flattenImages( Image *flattendImage_,
+		      InputIterator first_,
+		      InputIterator last_ ) {
+    MagickLib::ExceptionInfo exceptionInfo;
+    MagickLib::GetExceptionInfo( &exceptionInfo );
+    linkImages( first_, last_ );
+    MagickLib::Image* image = MagickLib::FlattenImages( first_->image(),
+							&exceptionInfo );
+    unlinkImages( first_, last_ );
+    flattendImage_->replaceImage( image );
+    throwException( exceptionInfo );
+  }
+
   // Replace the colors of a sequence of images with the closest color
   // from a reference image.
   // Set dither_ to true to enable dithering.  Set measureError_ to
@@ -2147,7 +2225,7 @@ namespace Magick
     MagickLib::GetExceptionInfo( &exceptionInfo );
     linkImages( first_, last_ );
     MagickLib::MapImages( first_->image(),
-			  mapImage_->image(),
+			  mapImage_.constImage(),
 			  dither_ );
     MagickLib::GetImageException( first_->image(), &exceptionInfo );
     if ( exceptionInfo.severity != MagickLib::UndefinedException )
@@ -2171,8 +2249,8 @@ namespace Magick
 	  }
 	
 	// Udate DirectClass representation of pixels
-	MagickLib::SyncImage( _imgRef->image() );
-	if ( _imgRef->image()->exception.severity > MagickLib::UndefinedException )
+	MagickLib::SyncImage( image );
+	if ( image->exception.severity > MagickLib::UndefinedException )
 	  {
 	    unlinkImages( first_, last_ );
 	    throwException( exceptionInfo );
@@ -2194,26 +2272,6 @@ namespace Magick
 
     MagickLib::MontageInfo* montageInfo =
       static_cast<MagickLib::MontageInfo*>(MagickLib::AcquireMemory(sizeof(MagickLib::MontageInfo)));
-    MagickLib::ImageInfo* imageInfo = first_->imageInfo();
-    MagickLib::GetMontageInfo( imageInfo, montageInfo );
-
-    // Set some default options based on current imageInfo settings.
-    montageInfo->background_color = first_->backgroundColor();
-
-    montageInfo->border_color = first_->borderColor();
-
-    montageInfo->matte_color = first_->matteColor();
-
-    montageInfo->stroke = first_->strokeColor();
-
-    montageInfo->fill = first_->fillColor();
-
-    if ( first_->font().length() != 0 )
-      Magick::CloneString ( &montageInfo->font,
-			    first_->font() );
-
-    if ( first_->fontPointsize() != 0 )
-      montageInfo->pointsize = first_->fontPointsize();
 
     // Update montage options with those set in montageOpts_
     montageOpts_.updateMontageInfo( *montageInfo );
@@ -2296,7 +2354,6 @@ namespace Magick
     MagickLib::GetExceptionInfo( &exceptionInfo );
     linkImages( first_, last_ );
     MagickLib::Image* image = MagickLib::MosaicImages( first_->image(),
-						       stack_,
 						       &exceptionInfo ); 
     unlinkImages( first_, last_ );
     mosaicImage_->replaceImage( image );
@@ -2309,6 +2366,9 @@ namespace Magick
   void quantizeImages( InputIterator first_,
 		       InputIterator last_,
 		       bool measureError_ = false ) {
+    MagickLib::ExceptionInfo exceptionInfo;
+    MagickLib::GetExceptionInfo( &exceptionInfo );
+
     linkImages( first_, last_ );
 
     MagickLib::QuantizeImages( first_->options()->quantizeInfo(),
@@ -2328,7 +2388,7 @@ namespace Magick
 	  MagickLib::QuantizationError( image );
 
 	// Update DirectClass representation of pixels
-	MagickLib::SyncImage( _imgRef->image() );
+	MagickLib::SyncImage( image );
 
 	// Next image
 	image=image->next;
@@ -2356,7 +2416,7 @@ namespace Magick
     MagickLib::ExceptionInfo exceptionInfo;
     MagickLib::GetExceptionInfo( &exceptionInfo );
     MagickLib::Image *images = MagickLib::BlobToImage( options.imageInfo(),
-						       static_cast<const char *>(blob_.data()),
+						       static_cast<void *>(blob_.data()),
 						       blob_.length(), &exceptionInfo );
     insertImages( sequence_, images, options );
     throwException( exceptionInfo );
@@ -2432,4 +2492,4 @@ namespace Magick
 
 } // namespace Magick
 
-#endif // MagickSTL_header
+#endif // Magick_STL_header
