@@ -1,8 +1,8 @@
 /*
   ImageMagick Image Methods.
 */
-#ifndef _IMAGE_H
-#define _IMAGE_H
+#ifndef _MAGICK_IMAGE_H
+#define _MAGICK_IMAGE_H
 
 #if defined(__cplusplus) || defined(c_plusplus)
 extern "C" {
@@ -13,7 +13,6 @@ extern "C" {
   Color quantum is [0..65535].
 */
 #define DownScale(quantum)  ((quantum)/257)
-#define HexColorFormat "#%04x%04x%04x%04x"
 #define MaxRGB  65535L
 #define QuantumDepth  16
 #define UpScale(quantum)  (257*(quantum))
@@ -26,7 +25,6 @@ typedef unsigned short Quantum;
   Color quantum is [0..255].
 */
 #define DownScale(quantum)  (quantum)
-#define HexColorFormat "#%02x%02x%02x%02x"
 #define MaxRGB  255L
 #define QuantumDepth  8
 #define UpScale(quantum)  (quantum)
@@ -38,39 +36,9 @@ typedef unsigned char Quantum;
 #define OpaqueOpacity  0
 #define TransparentOpacity  MaxRGB
 
-/*
-  3D effects.
-*/
-#define AccentuateModulate  UpScale(80)
-#define HighlightModulate  UpScale(125)
-#define ShadowModulate  UpScale(135)
-#define DepthModulate  UpScale(185)
-#define TroughModulate  UpScale(110)
-
 /*
   Typedef declarations.
 */
-typedef struct _AffineMatrix
-{
-  double
-    sx,
-    rx,
-    ry,
-    sy,
-    tx,
-    ty;
-} AffineMatrix;
-
-typedef struct _Ascii85Info
-{
-  int
-    offset,
-    line_break;
-
-  unsigned char
-    buffer[10];
-} Ascii85Info;
-
 typedef struct _PointInfo
 {
   double
@@ -115,21 +83,22 @@ typedef struct _RectangleInfo
     y;
 } RectangleInfo;
 
-typedef struct _BoundingBox
+typedef struct _Ascii85Info
 {
-  double
-    width,
-    height,
-    x,
-    y;
-} BoundingBox;
+  int
+    offset,
+    line_break;
+
+  unsigned char
+    buffer[10];
+} Ascii85Info;
 
 typedef struct _BlobInfo
 {
   unsigned int
     mapped;
 
-  char
+  unsigned char
     *data;
 
   off_t
@@ -140,6 +109,9 @@ typedef struct _BlobInfo
     extent,
     quantum;
 
+  unsigned int
+    eof;
+
   unsigned long
     signature;
 } BlobInfo;
@@ -153,6 +125,23 @@ typedef struct _ChromaticityInfo
     white_point;
 } ChromaticityInfo;
 
+typedef struct _ColorInfo
+{
+  char
+    *filename,
+    *name;
+
+  ComplianceType
+    compliance;
+
+  PixelPacket
+    color;
+  
+  struct _ColorInfo
+    *previous,
+    *next;
+} ColorInfo;
+
 typedef struct _ExceptionInfo
 {
   ExceptionType
@@ -251,6 +240,11 @@ typedef struct _SegmentInfo
     y2;
 } SegmentInfo;
 
+struct SemaphoreInfo;
+
+typedef struct SemaphoreInfo
+  SemaphoreInfo;
+
 typedef struct _Timer
 {
   double
@@ -285,11 +279,11 @@ typedef struct _Image
   FILE
     *file;
 
-  size_t
+  off_t
     filesize;
 
   int
-    pipe;
+    pipet;
 
   char
     magick[MaxTextExtent];
@@ -384,7 +378,7 @@ typedef struct _Image
   double
     blur;
 
-  size_t
+  off_t
     total_colors;
 
   unsigned int
@@ -420,6 +414,9 @@ typedef struct _Image
   ImageAttribute
     *attributes;
 
+  struct _Image
+    *clip_mask;
+
   void
     *cache;
 
@@ -429,6 +426,12 @@ typedef struct _Image
   void
     *client_data;
 
+  SemaphoreInfo
+    *semaphore;
+
+  int
+    reference_count;
+
   unsigned int
     orphan;
 
@@ -552,7 +555,18 @@ typedef struct _ImageInfo
 typedef struct _MagickInfo
 {
   char
-    *tag;
+    *name;
+
+  char
+    *description,
+    *module;
+
+  unsigned int
+    adjoin,
+    raw,
+    stealth,
+    blob_support,
+    thread_support;
 
   ImageInfo
     *image_info;
@@ -562,15 +576,7 @@ typedef struct _MagickInfo
 
   unsigned int
     (*encoder)(const ImageInfo *,Image *),
-    (*magick)(const unsigned char *,const unsigned int),
-    adjoin,
-    blob_support,
-    raw,
-    stealth;
-
-  char
-    *description,
-    *module;
+    (*magick)(const unsigned char *,const unsigned int);
 
   void
     *client_data;
@@ -606,15 +612,22 @@ extern MagickExport const char
   *SaveImageText,
   *SaveImagesText,
   *WriteBinaryType;
+
+extern MagickExport const unsigned int
+  DefaultCompressionQuality;
 
 /*
   Image utilities methods.
 */
 extern MagickExport char 
+  **GetColorList(const char *,int *),
   *GetImageMagick(const unsigned char *,const unsigned int),
   *GetMagickConfigurePath(const char *),
   *GetMagickVersion(unsigned int *);
 
+extern MagickExport ColorInfo
+  *GetColorInfo(const char *,ExceptionInfo *);
+
 extern MagickExport Image
   *AddNoiseImage(Image *,const NoiseType,ExceptionInfo *),
   *AllocateImage(const ImageInfo *),
@@ -636,6 +649,7 @@ extern MagickExport Image
   *EdgeImage(Image *,const double,ExceptionInfo *),
   *EmbossImage(Image *,const double,const double,ExceptionInfo *),
   *EnhanceImage(Image *,ExceptionInfo *),
+  *FlattenImages(Image *,ExceptionInfo *),
   *FlipImage(Image *,ExceptionInfo *),
   *FlopImage(Image *,ExceptionInfo *),
   *FrameImage(Image *,const FrameInfo *,ExceptionInfo *),
@@ -649,11 +663,13 @@ extern MagickExport Image
   *MontageImages(Image *,const MontageInfo *,ExceptionInfo *),
   *MorphImages(Image *,const unsigned int,ExceptionInfo *),
   *MosaicImages(Image *,ExceptionInfo *),
+  *MotionBlurImage(Image *,const double,const double,const double,
+    ExceptionInfo *),
   *OilPaintImage(Image *,const double,ExceptionInfo *),
   *PingImage(const ImageInfo *,ExceptionInfo *),
   *ReadImage(const ImageInfo *,ExceptionInfo *),
-  *ReadImages(const ImageInfo *,ExceptionInfo *),
   *ReduceNoiseImage(Image *,const double,ExceptionInfo *),
+  *ReferenceImage(Image *),
   *ResizeImage(Image *,const unsigned int,const unsigned int,const FilterTypes,
     const double,ExceptionInfo *),
   *RollImage(Image *,const int,const int,ExceptionInfo *),
@@ -662,6 +678,7 @@ extern MagickExport Image
   *ScaleImage(Image *,const unsigned int,const unsigned int,ExceptionInfo *),
   *ShadeImage(Image *,const unsigned int,double,double,ExceptionInfo *),
   *SharpenImage(Image *,const double,const double,ExceptionInfo *),
+  *ShaveImage(Image *,const RectangleInfo *,ExceptionInfo *),
   *ShearImage(Image *,const double,const double,ExceptionInfo *),
   *SpreadImage(Image *,const unsigned int,ExceptionInfo *),
   *SteganoImage(Image *,Image *,ExceptionInfo *),
@@ -679,14 +696,15 @@ extern MagickExport ImageType
   GetImageType(Image *);
 
 extern MagickExport IndexPacket
-  *(*GetIndexes)(const Image *);
+  *GetIndexes(const Image *),
+  ValidateColormapIndex(Image *,const int);
 
 extern MagickExport int
   ParseGeometry(const char *,int *,int *,unsigned int *,unsigned int *),
   ParseImageGeometry(const char *,int *,int *,unsigned int *,unsigned int *);
 
 extern MagickExport MagickInfo
-  *GetMagickInfo(const char *),
+  *GetMagickInfo(const char *,ExceptionInfo *exception),
   *RegisterMagickInfo(MagickInfo *),
   *SetMagickInfo(const char *);
 
@@ -694,16 +712,19 @@ extern MagickExport MontageInfo
   *CloneMontageInfo(const ImageInfo *,const MontageInfo *);
 
 extern MagickExport PixelPacket
-  *(*GetImagePixels)
-    (Image *,const int,const int,const unsigned int,const unsigned int),
-  (*GetOnePixel)(Image *,const int,const int),
-  *(*GetPixels)(const Image *),
-  *(*SetImagePixels)
-    (Image *,const int,const int,const unsigned int,const unsigned int);
+  *GetImagePixels(Image *,const int,const int,const unsigned int,
+    const unsigned int),
+  GetOnePixel(Image *,const int,const int),
+  *GetPixels(const Image *),
+  *SetImagePixels(Image *,const int,const int,const unsigned int,
+    const unsigned int);
 
 extern MagickExport RectangleInfo
   GetImageBoundingBox(Image *);
 
+extern MagickExport off_t
+  GetNumberColors(Image *,FILE *);
+
 extern MagickExport unsigned int
   AllocateImageColormap(Image *,const unsigned int),
   AnimateImages(const ImageInfo *image_info,Image *image),
@@ -720,11 +741,14 @@ extern MagickExport unsigned int
   IsGeometry(const char *),
   IsGrayImage(Image *),
   IsImagesEqual(Image *,Image *),
+  IsImageTainted(const Image *),
+  IsMagickConflict(const char *),
   IsMonochromeImage(Image *),
   IsOpaqueImage(Image *),
   IsPseudoClass(Image *),
   IsSubimage(const char *,const unsigned int),
-  IsImageTainted(const Image *),
+  ListColorInfo(FILE *,ExceptionInfo *),
+  ListMagickInfo(FILE *,ExceptionInfo *),
   ModulateImage(Image *,const char *),
   MogrifyImage(const ImageInfo *,const int,char **,Image **),
   MogrifyImages(const ImageInfo *,const int,char **,Image **),
@@ -732,23 +756,25 @@ extern MagickExport unsigned int
   NormalizeImage(Image *),
   OpaqueImage(Image *,const PixelPacket,const PixelPacket),
   PlasmaImage(Image *,const SegmentInfo *,int,int),
-  PopImagePixels(const Image *,const QuantumType,unsigned char *),
+  PopImagePixels(Image *,const QuantumType,unsigned char *),
   ProfileImage(Image *,const char *,const char *),
-  PushImagePixels(const Image *,const QuantumType,const unsigned char *),
+  PushImagePixels(Image *,const QuantumType,const unsigned char *),
   QueryColorDatabase(const char *,PixelPacket *),
+  QueryColorname(Image *,const PixelPacket *,const ComplianceType,char *),
   RaiseImage(Image *,const RectangleInfo *,const int),
   ReadStream(const ImageInfo *,int (*)(const Image *,const void *,const size_t),
     ExceptionInfo *),
   RGBTransformImage(Image *,const ColorspaceType),
+  SetImageClipMask(Image *,Image *),
   SetImageDepth(Image *,const unsigned int),
-  SetImageInfo(ImageInfo *,const unsigned int),
+  SetImageInfo(ImageInfo *,const unsigned int,ExceptionInfo *),
   SignatureImage(Image *),
   SortColormapByIntensity(Image *),
-  (*SyncImagePixels)(Image *),
+  SyncImagePixels(Image *),
   ThresholdImage(Image *,const double),
   TransformRGBImage(Image *,const ColorspaceType),
   TransmitImage(Image *,ImageInfo *,const TransmitType,void *,void *),
-  TransparentImage(Image *,const PixelPacket),
+  TransparentImage(Image *,const PixelPacket,const unsigned int),
   UnregisterMagickInfo(const char *),
   WriteImage(const ImageInfo *,Image *),
   WriteStream(ImageInfo *,Image *,
@@ -756,35 +782,36 @@ extern MagickExport unsigned int
 
 extern MagickExport void
   AllocateNextImage(const ImageInfo *,Image *),
-  (*CloseImagePixels)(Image *),
+  CloseImagePixels(Image *),
   CompressColormap(Image *),
   CycleColormapImage(Image *,const int),
   DescribeImage(Image *,FILE *,const unsigned int),
+  DestroyColorInfo(void),
+  DestroyConstitute(void),
   DestroyImage(Image *),
   DestroyImageInfo(ImageInfo *),
-  (*DestroyImagePixels)(Image *),
+  DestroyImagePixels(Image *),
   DestroyImages(Image *),
+  DestroyMagick(void),
   DestroyMagickInfo(void),
   DestroyMontageInfo(MontageInfo *),
   GetImageInfo(ImageInfo *),
   GetMontageInfo(const ImageInfo *,MontageInfo *),
-  GetPageInfo(RectangleInfo *),
-  GetPixelPacket(PixelPacket *),
-  ListMagickInfo(FILE *),
-  MagickIncarnate(const char *),
+  InitializeMagick(const char *),
+  ModifyImage(Image**,ExceptionInfo *),
   Register8BIMImage(void),
   RegisterARTImage(void),
   RegisterAVIImage(void),
   RegisterAVSImage(void),
   RegisterBIEImage(void),
   RegisterBMPImage(void),
-  RegisterBMP24Image(void),
   RegisterCMYKImage(void),
   RegisterCUTImage(void),
   RegisterDCMImage(void),
   RegisterDCXImage(void),
   RegisterDIBImage(void),
   RegisterDPSImage(void),
+  RegisterDPXImage(void),
   RegisterEPDFImage(void),
   RegisterEPIImage(void),
   RegisterEPSImage(void),
@@ -815,7 +842,7 @@ extern MagickExport void
   RegisterJBIGImage(void),
   RegisterJPGImage(void),
   RegisterJPEGImage(void),
-  RegisterJPEG24Image(void),
+  RegisterJP2Image(void),
   RegisterLABELImage(void),
   RegisterLOGOImage(void),
   RegisterMAPImage(void),
@@ -839,7 +866,6 @@ extern MagickExport void
   RegisterPDFImage(void),
   RegisterPICImage(void),
   RegisterPICTImage(void),
-  RegisterPICT24Image(void),
   RegisterPIXImage(void),
   RegisterPLASMAImage(void),
   RegisterPGMImage(void),
@@ -870,7 +896,6 @@ extern MagickExport void
   RegisterTGAImage(void),
   RegisterTIFImage(void),
   RegisterTIFFImage(void),
-  RegisterTIFF24Image(void),
   RegisterTILEImage(void),
   RegisterTIMImage(void),
   RegisterTTFImage(void),
@@ -893,8 +918,9 @@ extern MagickExport void
   RegisterXVImage(void),
   RegisterXWDImage(void),
   RegisterYUVImage(void),
-  SetImage(Image *,Quantum),
+  SetImage(Image *,const Quantum),
   SetImageOpacity(Image *,const unsigned int),
+  SetImageType(Image *,const ImageType),
   SolarizeImage(Image *,const double),
   SyncImage(Image *),
   TextureImage(Image *,Image *),
@@ -907,12 +933,13 @@ extern MagickExport void
   UnregisterAVSImage(void),
   UnregisterBIEImage(void),
   UnregisterBMPImage(void),
-  UnregisterBMP24Image(void),
   UnregisterCMYKImage(void),
+  UnregisterCUTImage(void),
   UnregisterDCMImage(void),
   UnregisterDCXImage(void),
   UnregisterDIBImage(void),
   UnregisterDPSImage(void),
+  UnregisterDPXImage(void),
   UnregisterEPDFImage(void),
   UnregisterEPIImage(void),
   UnregisterEPSImage(void),
@@ -943,7 +970,7 @@ extern MagickExport void
   UnregisterJBIGImage(void),
   UnregisterJPGImage(void),
   UnregisterJPEGImage(void),
-  UnregisterJPEG24Image(void),
+  UnregisterJP2Image(void),
   UnregisterLABELImage(void),
   UnregisterLOGOImage(void),
   UnregisterMAPImage(void),
@@ -967,7 +994,6 @@ extern MagickExport void
   UnregisterPDFImage(void),
   UnregisterPICImage(void),
   UnregisterPICTImage(void),
-  UnregisterPICT24Image(void),
   UnregisterPIXImage(void),
   UnregisterPLASMAImage(void),
   UnregisterPGMImage(void),
@@ -998,7 +1024,6 @@ extern MagickExport void
   UnregisterTGAImage(void),
   UnregisterTIFImage(void),
   UnregisterTIFFImage(void),
-  UnregisterTIFF24Image(void),
   UnregisterTILEImage(void),
   UnregisterTIMImage(void),
   UnregisterTTFImage(void),
